#
# spec file for package ghc-free
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name free
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        5.2
Release:        4.2
Summary:        Monads for free
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/6.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-comonad-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-distributive-devel
BuildRequires:  ghc-distributive-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-indexed-traversable-devel
BuildRequires:  ghc-indexed-traversable-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-profunctors-devel
BuildRequires:  ghc-profunctors-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroupoids-devel
BuildRequires:  ghc-semigroupoids-prof
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-th-abstraction-prof
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-base-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
Free monads are useful for many tree-like structures and domain specific
languages.

If 'f' is a 'Functor' then the free 'Monad' on 'f' is the type of trees whose
nodes are labeled with the constructors of 'f'. The word "free" is used in the
sense of "unrestricted" rather than "zero-cost": 'Free f' makes no constraining
assumptions beyond those given by 'f' and the definition of 'Monad'.
As used here it is a standard term from the mathematical theory of adjoint
functors.

Cofree comonads are dual to free monads. They provide convenient ways to talk
about branching streams and rose-trees, and can be used to annotate syntax
trees. The cofree comonad can be seen as a stream parameterized by a 'Functor'
that controls its branching factor.

More information on free monads, including examples, can be found in the
following blog posts: <https://ekmett.github.io/reader/2008/monads-for-free/>
<https://ekmett.github.io/reader/2011/free-monads-for-less/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown doc examples

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Dec  5 2024 Peter Simons <psimons@suse.com>
- Update free to version 5.2 revision 6.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu May 16 2024 Peter Simons <psimons@suse.com>
- Update free to version 5.2 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Mar 17 2024 Peter Simons <psimons@suse.com>
- Update free to version 5.2 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Sep 30 2023 Peter Simons <psimons@suse.com>
- Update free to version 5.2 revision 3.
  5.2 [2023.03.12]
  - ---------------
  * Drop support for GHC 7.10 and earlier.
  * Drop redundant `Monad` constraints on many functions and instances. These
    constraints were only present for compatibility with pre-7.10 versions of
    GHC, which `free` no longer supports.
  * Add `Eq`, `Eq1`, `Ord`, `Ord1`, and `Foldable` instances for `Ap` in
    `Control.Applicative.Free`.
  * Switch out `bifunctors` dependency for `bifunctor-classes-compat`.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Mar 12 2023 Peter Simons <psimons@suse.com>
- Update free to version 5.1.10 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Feb 27 2023 Peter Simons <psimons@suse.com>
- Update free to version 5.1.10 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Nov 30 2022 Peter Simons <psimons@suse.com>
- Update free to version 5.1.10.
  5.1.10 [2022.11.30]
  - ------------------
  * Add a `MonadFail` instance for `FT`.
* Sat Jul 23 2022 Peter Simons <psimons@suse.com>
- Update free to version 5.1.9 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jun 26 2022 Peter Simons <psimons@suse.com>
- Update free to version 5.1.9.
  5.1.9 [2022.06.26]
  - -----------------
  * Simplify the `Eq` and `Ord` instances for `FT` to avoid the use of
    overlapping instances.
  5.1.8 [2022.05.07]
  - -----------------
  * Generalize the `Monad` constraint in the type signatures for
    `hoistFreeT` in `Control.Monad.Trans.Free` and `Control.Monad.Trans.Free.Ap`
    to a `Functor` constraint.
  * Allow building with `transformers-0.6.*` and `mtl-2.3.*`.
* Sun Dec 12 2021 Peter Simons <psimons@suse.com>
- Update free to version 5.1.7 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Apr 30 2021 psimons@suse.com
- Update free to version 5.1.7.
  5.1.7 [2021.04.30]
  - -----------------
  * Enable `FlexibleContexts` in `Control.Monad.Trans.Free.Church` to allow
    building with GHC 9.2.
* Mon Jan  4 2021 psimons@suse.com
- Update free to version 5.1.6.
  5.1.6 [2020.12.31]
  - -----------------
  * Explicitly mark modules as `Safe`.
* Sun Dec 27 2020 psimons@suse.com
- Update free to version 5.1.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec 16 2020 psimons@suse.com
- Update free to version 5.1.5.
  5.1.5 [2020.12.16]
  - -----------------
  * Move `indexed-traversable` (`FunctorWithIndex` etc) instances from `lens`.
* Tue Oct  6 2020 psimons@suse.com
- Update free to version 5.1.4.
  5.1.4 [2020.10.01]
  - -----------------
  * Allow building with `template-haskell-2.17.0.0` (GHC 9.0).
* Mon Aug 31 2020 psimons@suse.com
- Update free to version 5.1.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed Nov 27 2019 psimons@suse.com
- Update free to version 5.1.3.
  5.1.3 [2019.11.26]
  - -----------------
  * Allow building with `template-haskell-2.16` (GHC 8.10).
  * Add `Eq{1,2}`, `Ord{1,2}`, `Read{1,2}`, and `Show{1,2}` instances for
    `CofreeF`.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Aug 28 2019 psimons@suse.com
- Update free to version 5.1.2.
  5.1.2 [2019.08.27]
  - -----------------
  * Implement more performant versions of `some` and `many` in the `Alternative`
    instance for the final `Alt` encoding.
* Fri May  3 2019 psimons@suse.com
- Update free to version 5.1.1.
  5.1.1 [2019.05.02]
  - -----------------
  * Allow building with `base-4.13` (GHC 8.8).
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update free to version 5.1.
  5.1 [2018.07.03]
  - ---------------
  * Generalize the type of `_Free`.
  * Allow building with `containers-0.6`.
  * Avoid incurring some dependencies when using recent GHCs.
  5.0.2 [2018.04.25]
  - -----------------
  * Add `Generic` and `Generic1` instances where possible.
* Mon May 14 2018 psimons@suse.com
- Update free to version 5.0.2.
  * Add a `Semigroup` instance for `IterT`.
  * Add `MonadFail` instances for `IterT` and `FreeT`.
  * Add a `Comonad` instance for the free `Applicative`, `Ap`.
  * Add `Control.Monad.Free.Ap` and `Control.Monad.Trans.Free.Ap` modules, based
    on the "Applicative Effects in Free Monads" series of articles by Will
    Fancher.
  * Derive `Data` instances for `Free` and `Cofree`.
  * `Control.Monad.Free.TH` now properly supports `template-haskell-2.11.0.0`. In
    particular, it now supports `GadtC` and `RecGadtC`, which are new
    `template-haskell` forms for representing GADTs.
  * Add `telescoped_`, `shoots`, and `leaves` to `Control.Comonad.Cofree`
  * Add the `Control.Applicative.Free.Fast` module, based on Dave Menendez's
    article "Free Applicative Functors in Haskell"
  * Add `foldFreeT` to `Control.Monad.Trans.Free`
  * Improve the `foldMap` and `cutoff` functions for
    `Control.Monad.Free.Church.F`, and add a `Traversable`
  * Add a `MonadBase` instance for `FreeT`
  * Add a performance test comparing Free and Church interpreters
  * The use of `prelude-extras` has been removed. `free` now uses the
    `Data.Functor.Classes` module to give `free`'s datatypes instances of `Eq1`,
    `Ord1`, `Read1`, and `Show1`. Their `Eq`, `Ord`, `Read`, and `Show` instances
    have also been modified to incorporate these classes. For example, what
    previously existed as:
    ```haskell
    instance (Eq (f (Free f a)), Eq a) => Eq (Free f a) where
    ```
    has now been changed to:
    ```haskell
    instance (Eq1 f, Eq a) => Eq (Free f a) where
    ```
  * Remove redundant `Functor` constraints from `Control.Alternative.Free`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 4.12.4 revision 0 with cabal2obs.
* Mon Jan 18 2016 mimi.vx@gmail.com
- update to 4.12.4
  * Add instances for ExceptT: like ErrorT, but without an Error constraint.
  * Support containers
  * Support transformers 0.5
  * Removed a number of spurious class constraints.
  * Support comonad 5
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to 4.12.1
  * Add instances of MonadCatch and MonadThrow from exceptions to FT, FreeT and IterT.
  * semigroupoids 5, profunctors 5, and bifunctors 5 support.
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
